""" detects JIRA-style ticket number in commit messages

To activate, update your hgrc::

    [extensions]
    hgticket = path/to/hgticket.py

"""

from mercurial import commands, extensions, util
import re

def ticketed(orig, ui, repo, *pats, **opts):
    msg = opts['message']
    match = re.search('[A-Z][A-Z][A-Z]*?-[0-9][0-9]*', msg)
    if not match:
        raise util.Abort('commit message does not have ticket number')
    ui.status('ticket: detected ticket number "%s"\n' % match.group())
    return orig(ui, repo, *pats, **opts)

def uisetup(ui):
    if not hasattr(extensions, 'wrapcommand'):
        return
    extensions.wrapcommand(commands.table, 'commit', ticketed)



from setuptools import setup, find_packages

import os
lines = open(os.path.join(os.path.dirname(__file__), 'README')).read().strip().splitlines()

sdesc = lines[0]
ldesc = '\n'.join(lines[1:])

setup(name='hgticket',
    version='1.0',
    author='Eric Gazoni',
    author_email='eric.gazoni@adimian.com',
    description=sdesc,
    long_description=ldesc,
    py_modules=['hgticket'],
    license='MIT',
    zip_safe=True,
    url='http://bitbucket.org/adimian/hgticket',
    download_url='http://bitbucket.org/adimian/hgticket/downloads',
    keywords='mercurial hg scm jira ticket',
)
